## Board oscillator:

create_clock -period                        5.000     [ get_ports clk200MHz_p ]
set_property -dict { PACKAGE_PIN R4 IOSTANDARD DIFF_SSTL15 } [get_ports clk200MHz_p ]
set_property -dict { PACKAGE_PIN T4 IOSTANDARD DIFF_SSTL15 } [get_ports clk200MHz_n ]

## I/O-standard

set_property  CFGBVS                        VCCO      [ current_design ]
set_property  CONFIG_VOLTAGE                3.3       [ current_design ]

## SPI configuration

set_property  BITSTREAM.CONFIG.SPI_BUSWIDTH 4         [ current_design ]
set_property  CONFIG_MODE                   SPIx4     [ current_design ]
set_property  BITSTREAM.CONFIG.CONFIGRATE   50        [ current_design ]
set_property  BITSTREAM.GENERAL.COMPRESS    TRUE      [ current_design ]

## UART:

set_property -dict { PACKAGE_PIN Y12 IOSTANDARD LVCMOS33 } [ get_ports uart_rx ]
set_property -dict { PACKAGE_PIN Y11 IOSTANDARD LVCMOS33 } [ get_ports uart_tx ]

## LED:

set_property -dict { PACKAGE_PIN C17 IOSTANDARD LVCMOS33 } [ get_ports led[0] ]
set_property -dict { PACKAGE_PIN D17 IOSTANDARD LVCMOS33 } [ get_ports led[1] ]
set_property -dict { PACKAGE_PIN V20 IOSTANDARD LVCMOS33 } [ get_ports led[2] ]
set_property -dict { PACKAGE_PIN U20 IOSTANDARD LVCMOS33 } [ get_ports led[3] ]

## Buttons:

set_property -dict { PACKAGE_PIN B18 IOSTANDARD LVCMOS33 } [ get_ports btn[0] ]
set_property -dict { PACKAGE_PIN B17 IOSTANDARD LVCMOS33 } [ get_ports btn[1] ]
set_property -dict { PACKAGE_PIN A16 IOSTANDARD LVCMOS33 } [ get_ports btn[2] ]
set_property -dict { PACKAGE_PIN A15 IOSTANDARD LVCMOS33 } [ get_ports btn[3] ]

## Quad SPI Flash
set_property -dict { PACKAGE_PIN T19 IOSTANDARD LVCMOS33 } [ get_ports spi_csn ]
set_property -dict { PACKAGE_PIN P22 IOSTANDARD LVCMOS33 } [ get_ports spi_sdo ]
set_property -dict { PACKAGE_PIN R22 IOSTANDARD LVCMOS33 } [ get_ports spi_sdi ]

## Gigabit PHY:

set_property -dict { PACKAGE_PIN W10 IOSTANDARD LVCMOS33 PULLUP true           } [ get_ports eth_mdc     ]
set_property -dict { PACKAGE_PIN V10 IOSTANDARD LVCMOS33 PULLUP true SLEW SLOW } [ get_ports eth_mdio    ]

set_property -dict { PACKAGE_PIN L15 IOSTANDARD LVCMOS33 } [ get_ports eth_rstn    ]
set_property -dict { PACKAGE_PIN K18 IOSTANDARD LVCMOS33 } [ get_ports eth_rx_clk  ]
set_property -dict { PACKAGE_PIN M22 IOSTANDARD LVCMOS33 } [ get_ports eth_rx_dv   ]
set_property -dict { PACKAGE_PIN N22 IOSTANDARD LVCMOS33 } [ get_ports eth_rxd[0]  ]
set_property -dict { PACKAGE_PIN H18 IOSTANDARD LVCMOS33 } [ get_ports eth_rxd[1]  ]
set_property -dict { PACKAGE_PIN H17 IOSTANDARD LVCMOS33 } [ get_ports eth_rxd[2]  ]
set_property -dict { PACKAGE_PIN K19 IOSTANDARD LVCMOS33 } [ get_ports eth_rxd[3]  ]
set_property -dict { PACKAGE_PIN M21 IOSTANDARD LVCMOS33 } [ get_ports eth_rxd[4]  ]
set_property -dict { PACKAGE_PIN L21 IOSTANDARD LVCMOS33 } [ get_ports eth_rxd[5]  ]
set_property -dict { PACKAGE_PIN N20 IOSTANDARD LVCMOS33 } [ get_ports eth_rxd[6]  ]
set_property -dict { PACKAGE_PIN M20 IOSTANDARD LVCMOS33 } [ get_ports eth_rxd[7]  ]
set_property -dict { PACKAGE_PIN N19 IOSTANDARD LVCMOS33 } [ get_ports eth_rxerr   ]

set_property -dict { PACKAGE_PIN L18 IOSTANDARD LVCMOS33 } [ get_ports eth_gtx_clk ]
set_property -dict { PACKAGE_PIN J17 IOSTANDARD LVCMOS33 } [ get_ports eth_tx_clk  ]
set_property -dict { PACKAGE_PIN M16 IOSTANDARD LVCMOS33 } [ get_ports eth_tx_en   ]
set_property -dict { PACKAGE_PIN M15 IOSTANDARD LVCMOS33 } [ get_ports eth_txd[0]  ]
set_property -dict { PACKAGE_PIN L14 IOSTANDARD LVCMOS33 } [ get_ports eth_txd[1]  ]
set_property -dict { PACKAGE_PIN K16 IOSTANDARD LVCMOS33 } [ get_ports eth_txd[2]  ]
set_property -dict { PACKAGE_PIN L16 IOSTANDARD LVCMOS33 } [ get_ports eth_txd[3]  ]
set_property -dict { PACKAGE_PIN K17 IOSTANDARD LVCMOS33 } [ get_ports eth_txd[4]  ]
set_property -dict { PACKAGE_PIN L20 IOSTANDARD LVCMOS33 } [ get_ports eth_txd[5]  ]
set_property -dict { PACKAGE_PIN L19 IOSTANDARD LVCMOS33 } [ get_ports eth_txd[6]  ]
set_property -dict { PACKAGE_PIN L13 IOSTANDARD LVCMOS33 } [ get_ports eth_txd[7]  ]
set_property -dict { PACKAGE_PIN M13 IOSTANDARD LVCMOS33 } [ get_ports eth_txerr   ]

set_property -dict { PACKAGE_PIN N18 IOSTANDARD LVCMOS33 } [ get_ports eth_col     ]
set_property -dict { PACKAGE_PIN M18 IOSTANDARD LVCMOS33 } [ get_ports eth_crs     ]

create_clock -period 8.000 -name rx_clk [ get_ports eth_rx_clk]
create_clock -period 8.000 -name tx_clk [ get_ports eth_gtx_clk]

set_false_path -reset_path -from [ get_clocks clk200MHz_p ] -to [ get_clocks eth_rx_clk ]

set_property CLOCK_DEDICATED_ROUTE FALSE [ get_nets eth_tx_clk_IBUF]
